=== added directory 'lander'
=== added directory 'lander/bin'
=== added file 'lander/bin/lander_archiver.py'
--- lander/bin/lander_archiver.py	1970-01-01 00:00:00 +0000
+++ lander/bin/lander_archiver.py	2013-12-11 22:57:57 +0000
@@ -0,0 +1,66 @@
+#!/usr/bin/env python
+
+import argparse
+import json
+import sys
+import urllib2
+
+def parse_arguments():
+    parser = argparse.ArgumentParser(
+        description='Archives the provided job artifacts to the data store.')
+    parser.add_argument('--build-url',
+                        required=True,
+                        help='The build to archive.')
+    return parser.parse_args()
+
+
+def _get_build_api_json_url(url):
+    return '/'.join([url, 'api', 'json'])
+
+
+def _get_artifact_list(url):
+    req = urllib2.Request(_get_build_api_json_url(url))
+    f = urllib2.urlopen(req)
+    response = f.read()
+    f.close()
+    data = json.loads(response)
+    artifact_list = []
+    for artifact in data['artifacts']:
+        artifact_list.append(artifact['relativePath'])
+
+    return artifact_list
+
+
+def _get_console_log_url(url):
+    return '/'.join([url, 'consoleText'])
+
+
+def _get_artifact_url(url, artifact_name):
+    return '/'.join([url, 'artifact', artifact_name])
+
+
+def _dump_artifact(url):
+    req = urllib2.Request(url)
+    f = urllib2.urlopen(req)
+    response = f.read()
+    f.close()
+    print(response)
+
+
+def main():
+    args = parse_arguments()
+
+    #TODO: Do something useful with the artifacts.
+    #TODO: For now, just dump them to the console.
+    print('Console Log:')
+    print('************')
+    _dump_artifact(_get_console_log_url(args.build_url))
+    artifact_list = _get_artifact_list(args.build_url)
+    for artifact in artifact_list:
+        print('Artifact: {}'.format(artifact))
+        print('**********' + ('*' * len(artifact)))
+        _dump_artifact(_get_artifact_url(args.build_url, artifact))
+
+
+if __name__ == '__main__':
+    main()

=== added file 'lander/bin/lander_merge_parameters.py'
--- lander/bin/lander_merge_parameters.py	1970-01-01 00:00:00 +0000
+++ lander/bin/lander_merge_parameters.py	2013-12-11 22:57:57 +0000
@@ -0,0 +1,45 @@
+#!/usr/bin/env python
+
+import argparse
+import json
+import sys
+import urllib2
+
+def parse_arguments():
+    parser = argparse.ArgumentParser(
+        description='Merges a service result into the prior results.')
+    parser.add_argument('--service',
+                        required=True,
+                        help='The service name which generated the results.')
+    parser.add_argument('--result-file',
+                        required=True,
+                        help='The results from the given service.')
+    parser.add_argument('--prior-file',
+                        default=None,
+                        help='Results file from prior calls.')
+    parser.add_argument('--output-file',
+                        required=True,
+                        help='The new merged results file.')
+    return parser.parse_args()
+
+
+
+def main():
+    args = parse_arguments()
+
+    if args.prior_file:
+        with open(args.prior_file) as prior_file:
+            data = json.loads(prior_file.read())
+    else:
+        data = {}
+    with open(args.result_file) as result_file:
+        data[args.service] = json.loads(result_file.read())
+
+    with open(args.output_file, 'w') as output_file:
+        output_file.write(json.dumps(data))
+        output_file.write('\n')
+
+
+if __name__ == '__main__':
+    main()
+

=== added file 'lander/bin/lander_service_wrapper.py'
--- lander/bin/lander_service_wrapper.py	1970-01-01 00:00:00 +0000
+++ lander/bin/lander_service_wrapper.py	2013-12-11 22:57:57 +0000
@@ -0,0 +1,112 @@
+#!/usr/bin/env python
+
+import argparse
+import logging
+import json
+import os.path
+import sys
+import yaml
+
+format_list = {'json', 'yaml'}
+# Make up some resonable data returned from each service
+data = {
+    'master': {
+        'autopilot': {
+            'version': '1.3.1+13.10.20131003.1-0ubuntu2~fginther.1',
+            'files': [
+                '/path/to/changes',
+                '/path/to/dsc',
+                '/path/to/diff.gz']}},
+    'ppa_assigner': {
+        'result': 'PASSED',
+        'ppa': 'ppa:team/ppa'},
+    'bsbuilder': {
+        'result': 'PASSED',
+        'version': '1.3.1+13.10.20131003.1-0ubuntu2~fginther.1',
+        'packages': [
+            'autopilot-desktop',
+            'autopilot-touch',
+            'python-autopilot',
+            'python-autopilot-test',
+            'python-autopilot-trace',
+            'python-autopilot-vis'],
+        'ppa': 'ppa:team/ppa'},
+    'image_builder': {
+        'result': 'PASSED',
+        'image': '/path/to/image'},
+    'test_runner': {
+        'result': 'PASSED',
+        'artifacts': [
+            '/path/to/artifact1',
+            '/path/to/artifact2']},
+    'publisher': {
+        'result': 'PASSED',
+        'image': '/path/to/image'},
+}
+
+logger = logging.getLogger('lander_service_wrapper')
+stdout_handler = logging.StreamHandler(stream=sys.stdout)
+formatter = logging.Formatter('%(levelname)s: %(message)s')
+stdout_handler.setFormatter(formatter)
+logger.addHandler(stdout_handler)
+
+
+def parse_arguments():
+    parser = argparse.ArgumentParser(
+        description='Wraps the REST API calls with a progress queue monitor.')
+    parser.add_argument('--service',
+                        required=True,
+                        help='The service name to call.')
+    parser.add_argument('--input-file',
+                        required=True,
+                        help='File containing all of the input parameters.')
+    parser.add_argument('--input-format',
+                        required=False,
+                        default='json',
+                        help='''Format for the input parameter file
+                        {}.'''.format(format_list))
+    parser.add_argument('--output-file',
+                        required=True,
+                        help='File to store the API call results.')
+    parser.add_argument('--output-format',
+                        required=False,
+                        default='json',
+                        help='''Format for API call results
+                        {}.'''.format(format_list))
+    return parser.parse_args()
+
+
+def main():
+    args = parse_arguments()
+    if args.service not in data:
+        logger.error("ERROR: Unknown service: {}".format(args.service))
+        sys.exit(1)
+
+    if args.input_format not in format_list:
+        logger.error(
+            "ERROR: Unknown input format: {}".format(args.input_format))
+        sys.exit(1)
+
+    if args.output_format not in format_list:
+        logger.error(
+            "ERROR: Unknown output format: {}".format(args.output_format))
+        sys.exit(1)
+
+    logger.debug('Executing service wrapper: {}'.format(args.service))
+    # TODO: Call the service and collect the returned data
+    # For now, canned responses are used as the return data
+    with open(args.output_file, 'w') as output_file:
+        out_data = None
+        if args.output_format == 'json':
+            out_data = json.dumps(data[args.service])
+        elif args.output_format == 'yaml':
+            out_data = yaml.dump(data[args.service])
+        logger.debug('Output data [{}]: {}'.format(args.output_format,
+                                                   out_data))
+        output_file.write('{}\n'.format(out_data))
+    logger.debug('Exit 0')
+    sys.exit(0)
+
+
+if __name__ == '__main__':
+    main()

